@@ -4,7 +4,7 @@ using DiffEqBase
 using GeneralizedGenerated
 
 function SciMLBase.numargs(::GeneralizedGenerated.RuntimeFn{Args}) where {Args}
-    GeneralizedGenerated.from_type(Args) |> length
+    return GeneralizedGenerated.from_type(Args) |> length
 end
 
 end
