@@ -4,29 +4,33 @@ using DiffEqBase, Mooncake
 using DiffEqBase: SciMLBase
 using SciMLBase: ADOriginator, ChainRulesOriginator, MooncakeOriginator
 import Mooncake: rrule!!, CoDual, zero_fcodual, @is_primitive,
-                 @from_rrule, @zero_adjoint, @mooncake_overlay, MinimalCtx,
-                 NoPullback
+    @from_rrule, @zero_adjoint, @mooncake_overlay, MinimalCtx,
+    NoPullback
 
-@from_rrule(MinimalCtx,
+@from_rrule(
+    MinimalCtx,
     Tuple{
         typeof(DiffEqBase.solve_up),
         DiffEqBase.AbstractDEProblem,
         Union{Nothing, DiffEqBase.AbstractSensitivityAlgorithm},
         Any,
         Any,
-        Any
+        Any,
     },
-    true,)
+    true,
+)
 
 # Dispatch for auto-alg
-@from_rrule(MinimalCtx,
+@from_rrule(
+    MinimalCtx,
     Tuple{
         typeof(DiffEqBase.solve_up),
         DiffEqBase.AbstractDEProblem,
         Union{Nothing, DiffEqBase.AbstractSensitivityAlgorithm},
         Any,
-        Any
+        Any,
     },
-    true,)
+    true,
+)
 
 end
