@@ -4,7 +4,7 @@ $(TYPEDEF)
 Holds a tableau which defines an explicit Runge-Kutta method.
 """
 mutable struct ExplicitRKTableau{MType <: AbstractMatrix, VType <: AbstractVector, S, IType} <:
-               ODERKTableau
+    ODERKTableau
     A::MType
     c::VType
     α::VType
@@ -17,13 +17,17 @@ mutable struct ExplicitRKTableau{MType <: AbstractMatrix, VType <: AbstractVecto
     stability_size::S
     B_interp::IType
 end
-function ExplicitRKTableau(A::MType, c::VType, α::VType, order;
+function ExplicitRKTableau(
+        A::MType, c::VType, α::VType, order;
         adaptiveorder = 0, αEEst = similar(α, 0),
         fsal = false, stability_size = 0.0,
-        d = similar(α, 0), B_interp::IType = nothing) where {MType, VType, IType}
+        d = similar(α, 0), B_interp::IType = nothing
+    ) where {MType, VType, IType}
     S = typeof(stability_size)
-    ExplicitRKTableau{MType, VType, S, IType}(A, c, α, αEEst, d, length(α), order, adaptiveorder,
-        fsal, stability_size, B_interp)
+    return ExplicitRKTableau{MType, VType, S, IType}(
+        A, c, α, αEEst, d, length(α), order, adaptiveorder,
+        fsal, stability_size, B_interp
+    )
 end
 
 """
@@ -32,7 +36,7 @@ $(TYPEDEF)
 Holds a tableau which defines an implicit Runge-Kutta method.
 """
 mutable struct ImplicitRKTableau{MType <: AbstractMatrix, VType <: AbstractVector} <:
-               ODERKTableau
+    ODERKTableau
     A::MType
     c::VType
     α::VType
@@ -41,7 +45,9 @@ mutable struct ImplicitRKTableau{MType <: AbstractMatrix, VType <: AbstractVecto
     order::Int
     adaptiveorder::Int #The lower order of the pair. Only used for adaptivity.
 end
-function ImplicitRKTableau(A::MType, c::VType, α::VType, order;
-        adaptiveorder = 0, αEEst = VType()) where {MType, VType}
-    ImplicitRKTableau{MType, VType}(A, c, α, αEEst, length(α), order, adaptiveorder)
+function ImplicitRKTableau(
+        A::MType, c::VType, α::VType, order;
+        adaptiveorder = 0, αEEst = VType()
+    ) where {MType, VType}
+    return ImplicitRKTableau{MType, VType}(A, c, α, αEEst, length(α), order, adaptiveorder)
 end
