@@ -1,11 +1,11 @@
 using DiffEqBase, Test
 
 condition = function (u, t, integrator) # Event when event_f(u,t,k) == 0
-    t - 2.95
+    return t - 2.95
 end
 
 affect! = function (integrator)
-    integrator.u = integrator.u + 2
+    return integrator.u = integrator.u + 2
 end
 
 rootfind = true
@@ -23,7 +23,7 @@ cbs = CallbackSet(callback, CallbackSet())
 @test typeof(cbs.continuous_callbacks) <: Tuple
 
 condition = function (integrator)
-    true
+    return true
 end
 affect! = function (integrator) end
 save_positions = (true, false)
@@ -58,17 +58,21 @@ struct EmptyIntegrator
     u::Vector{Float64}
     tdir::Int
 end
-function DiffEqBase.find_callback_time(integrator::EmptyIntegrator,
-        callback::ContinuousCallback, counter)
-    1.0 + counter, 0.9 + counter, true, counter
+function DiffEqBase.find_callback_time(
+        integrator::EmptyIntegrator,
+        callback::ContinuousCallback, counter
+    )
+    return 1.0 + counter, 0.9 + counter, true, counter
 end
-function DiffEqBase.find_callback_time(integrator::EmptyIntegrator,
-        callback::VectorContinuousCallback, counter)
-    1.0 + counter, 0.9 + counter, true, counter
+function DiffEqBase.find_callback_time(
+        integrator::EmptyIntegrator,
+        callback::VectorContinuousCallback, counter
+    )
+    return 1.0 + counter, 0.9 + counter, true, counter
 end
 find_first_integrator = EmptyIntegrator([1.0, 2.0], 1)
 vector_affect! = function (integrator, idx)
-    integrator.u = integrator.u + idx
+    return integrator.u = integrator.u + idx
 end
 
 cond_1(u, t, integrator) = t - 1.0
@@ -82,7 +86,8 @@ cond_8(u, t, integrator) = t - 1.7
 cond_9(u, t, integrator) = t - 1.8
 cond_10(u, t, integrator) = t - 1.9
 # Setup a lot of callbacks so the recursive inference failure happens
-callbacks = (ContinuousCallback(cond_1, affect!),
+callbacks = (
+    ContinuousCallback(cond_1, affect!),
     ContinuousCallback(cond_2, affect!),
     ContinuousCallback(cond_3, affect!),
     ContinuousCallback(cond_4, affect!),
@@ -97,9 +102,34 @@ callbacks = (ContinuousCallback(cond_1, affect!),
     VectorContinuousCallback(cond_3, vector_affect!, 2),
     VectorContinuousCallback(cond_4, vector_affect!, 2),
     VectorContinuousCallback(cond_5, vector_affect!, 2),
-    VectorContinuousCallback(cond_6, vector_affect!, 2));
+    VectorContinuousCallback(cond_6, vector_affect!, 2),
+);
 function test_find_first_callback(callbacks, int)
-    @timed(DiffEqBase.find_first_continuous_callback(int, callbacks...))
+    return @timed(DiffEqBase.find_first_continuous_callback(int, callbacks...))
 end
 test_find_first_callback(callbacks, find_first_integrator);
 @test test_find_first_callback(callbacks, find_first_integrator).bytes == 0
+
+# https://github.com/SciML/DiffEqBase.jl/issues/1233
+@testset "Inexact rootfinding" begin
+    # function with irrational root (sqrt(2))
+    irrational_f(x, p = 0.0) = x^2 - 2
+
+    # Forward integration
+    is_forward = true
+    tspan = (1.0, 2.0)
+    before = DiffEqBase.find_root(irrational_f, tspan, SciMLBase.LeftRootFind)
+    after = DiffEqBase.find_root(irrational_f, tspan, SciMLBase.RightRootFind)
+    @test irrational_f(before) < 0.0
+    @test irrational_f(after) > 0.0
+    @test nextfloat(before) == after
+
+    # Backward integration
+    is_forward = false
+    tspan = (2.0, 1.0)
+    before = DiffEqBase.find_root(irrational_f, tspan, SciMLBase.LeftRootFind)
+    after = DiffEqBase.find_root(irrational_f, tspan, SciMLBase.RightRootFind)
+    @test irrational_f(before) > 0.0
+    @test irrational_f(after) < 0.0
+    @test nextfloat(after) == before
+end
