@@ -21,13 +21,17 @@ f(u, p, t) = begin
     [dx1, dx2, ddx1, ddx2]
 end
 
-sol = solve(ODEProblem(f, [5.0, 6.0, 0.0, 0.0], (0.0, T)),
+sol = solve(
+    ODEProblem(f, [5.0, 6.0, 0.0, 0.0], (0.0, T)),
     Rodas5P(),
-    callback = ContinuousCallback((u, _, _) -> u[1],
-        (integrator) -> (integrator.u[1] = 0; integrator.u[3] = 0)),
+    callback = ContinuousCallback(
+        (u, _, _) -> u[1],
+        (integrator) -> (integrator.u[1] = 0; integrator.u[3] = 0)
+    ),
     # callback = ContinuousCallback((u, _, _) -> u[1], (integrator) -> (integrator.u[3] = 0)),
-    reltol = 1e-5,
-    abstol = 1e-5)
+    reltol = 1.0e-5,
+    abstol = 1.0e-5
+)
 
 @show sol.stats
 
@@ -62,7 +66,7 @@ perror = [
     0.029177617589788596,
     0.03064986043089549,
     0.023280222517122397,
-    6.931251277770224
+    6.931251277770224,
 ]
 y_max = 0.002604806609572015
 u0 = [1, zeros(length(perror) - 1)...]
@@ -76,13 +80,17 @@ t_half_1 = 0.0
 affect2!(i) = (t_half_1 = i.t)
 
 prob = ODEProblem(model, u0, tspan, perror)
-sol = solve(prob,
+sol = solve(
+    prob,
     Rosenbrock23();
-    callback = CallbackSet(PositiveDomain(),
+    callback = CallbackSet(
+        PositiveDomain(),
         DiscreteCallback(condition, affect!),
-        ContinuousCallback(condition2, affect2!, terminate!)),
+        ContinuousCallback(condition2, affect2!, terminate!)
+    ),
     tstops = [1.0],
-    force_dtmin = true)
+    force_dtmin = true
+)
 
 # https://github.com/SciML/DiffEqBase.jl/issues/515 : Fixed
 
@@ -101,7 +109,7 @@ function attactor(du, u, p, t)
                     u.nodes[k][3],
                     u.nodes[k][4],
                     -β * u.nodes[k][3],
-                    -β * u.nodes[k][4]
+                    -β * u.nodes[k][4],
                 ]
             else
                 du.nodes[k][3:4] .+= α * (u.nodes[j][1:2] - u.nodes[k][1:2])
@@ -115,21 +123,23 @@ struct Thingy{B} <: AbstractMultiScaleArrayLeaf{B}
 end
 
 struct PhysicsLaw{T <: AbstractMultiScaleArray, B <: Number} <:
-       AbstractMultiScaleArrayHead{B}
+    AbstractMultiScaleArrayHead{B}
     nodes::Vector{T}
     values::Vector{B}
     end_idxs::Vector{Int}
 end
 
-Newton = construct(PhysicsLaw,
+Newton = construct(
+    PhysicsLaw,
     [
         Thingy([-700.0, -350.0, 0.0, 0.0]),
         Thingy([-550.0, -150.0, 0.0, 0.0]),
         Thingy([-600.0, 15.0, 0.0, 10.0]),
-        Thingy([200.0, -200.0, 5.0, -5.0])
-    ])
+        Thingy([200.0, -200.0, 5.0, -5.0]),
+    ]
+)
 
-parameters = [1e-2, 0.06]
+parameters = [1.0e-2, 0.06]
 
 function condition(out, u, t, integrator)
     i = 0
@@ -140,6 +150,7 @@ function condition(out, u, t, integrator)
             out[i] = sum(abs2, u.nodes[k][1:2] .- u.nodes[l][1:2]) - 10000
         end
     end
+    return
 end
 
 function affect!(integrator, idx)
@@ -167,8 +178,10 @@ function affect!(integrator, idx)
 
                 set_u!(integrator, u)
                 println(sqrt(sum(abs2, x₁ .- x₂)) - 100, ":", v₁ ./ v₂)
-                println(norm(v₁), ":", norm(v₂), ":", integrator.t, ":",
-                    integrator.t - t_last)
+                println(
+                    norm(v₁), ":", norm(v₂), ":", integrator.t, ":",
+                    integrator.t - t_last
+                )
                 global t_last = integrator.t
                 break
             end
@@ -176,9 +189,11 @@ function affect!(integrator, idx)
     end
 end
 
-cback = VectorContinuousCallback(condition,
+cback = VectorContinuousCallback(
+    condition,
     affect!,
-    (x -> Int(((x - 1) * x) / 2))(length(Newton.nodes)))
+    (x -> Int(((x - 1) * x) / 2))(length(Newton.nodes))
+)
 
 problemp = ODEProblem(attactor, Newton, (0.0, Inf), parameters)
 
@@ -195,15 +210,15 @@ end
 function f!(out, u, p, t)
     out[1] = 0
     out[2] = u[3]
-    out[3] = -1.0 * (u[2] - u[1])
+    return out[3] = -1.0 * (u[2] - u[1])
 end
 u0 = [0, 0, 1.0]
 function cond!(out, u, t, i)
     out[1] = u[3]
-    nothing
+    return nothing
 end
 function affect!(int, idx)
-    terminate!(int)
+    return terminate!(int)
 end
 cb = VectorContinuousCallback(cond!, affect!, nothing, 1)
 
@@ -224,8 +239,10 @@ prob = ODEProblem(odefun, [0.0, -1.0], (0.0, 1), 1; callback)
 end
 
 daefun = DAEFunction((du, u, p, t) -> [du[1] - u[2], u[2] - p])
-prob = DAEProblem(daefun, [0.0, 0.0], [0.0, -1.0], (0.0, 1), 1;
-    differential_vars = [true, false], callback)
+prob = DAEProblem(
+    daefun, [0.0, 0.0], [0.0, -1.0], (0.0, 1), 1;
+    differential_vars = [true, false], callback
+)
 sol = solve(prob, DFBDF())
 # test that the callback flipping p caused u[2] to get flipped.
 first_t = findfirst(isequal(0.5), sol.t)
@@ -234,12 +251,12 @@ first_t = findfirst(isequal(0.5), sol.t)
 # https://github.com/SciML/DiffEqBase.jl/issues/1231
 @testset "Successive callbacks in same integration step" begin
     cb = ContinuousCallback(
-        (u, t, integrator) -> t - 0e-8,
+        (u, t, integrator) -> t - 0.0e-8,
         (integrator) -> push!(record, 0)
     )
 
     vcb = VectorContinuousCallback(
-        (out, u, t, integrator) -> out .= (t - 1e-8, t - 2e-8),
+        (out, u, t, integrator) -> out .= (t - 1.0e-8, t - 2.0e-8),
         (integrator, event_index) -> push!(record, event_index),
         2
     )
