@@ -1,6 +1,6 @@
 using OrdinaryDiffEq
 function f(du, u, p, t)
-    du[1] = 1.01 * u[1]
+    return du[1] = 1.01 * u[1]
 end
 u0 = [0.0, 0.0]
 tspan = (0.0, 1.0)
@@ -10,13 +10,17 @@ n = 100
 initial_conditions = range(0, stop = 1, length = n)
 function prob_func(prob, i, repeat)
     prob.u0[1] = initial_conditions[i]
-    prob
+    return prob
 end
 ensemble_prob = EnsembleProblem(prob, prob_func = prob_func)
-sim_1 = solve(ensemble_prob, Tsit5(), EnsembleThreads(),
-    trajectories = 100)
-sim_2 = solve(ensemble_prob, Tsit5(), EnsembleDistributed(),
-    trajectories = 100)
+sim_1 = solve(
+    ensemble_prob, Tsit5(), EnsembleThreads(),
+    trajectories = 100
+)
+sim_2 = solve(
+    ensemble_prob, Tsit5(), EnsembleDistributed(),
+    trajectories = 100
+)
 ss_sol_1 = hcat(collect(EnsembleAnalysis.get_timepoint(sim_1, 0))...);
 ss_sol_2 = hcat(collect(EnsembleAnalysis.get_timepoint(sim_2, 0))...);
 
