@@ -3,9 +3,9 @@ using LabelledArrays
 using ADTypes
 
 function f(out, du, u, p, t)
-    out.x = -0.04u.x + 1e4 * u.y * u.z - du.x
-    out.y = +0.04u.x - 3e7 * u.y^2 - 1e4 * u.y * u.z - du.y
-    out.z = u.x + u.y + u.z - 1.0
+    out.x = -0.04u.x + 1.0e4 * u.y * u.z - du.x
+    out.y = +0.04u.x - 3.0e7 * u.y^2 - 1.0e4 * u.y * u.z - du.y
+    return out.z = u.x + u.y + u.z - 1.0
 end
 
 u₀ = LVector(x = 1.0, y = 0.0, z = 0.0)
@@ -19,7 +19,7 @@ sol = solve(prob, DImplicitEuler())
 
 function f1(du, u, p, t)
     du.x .= -1 .* u.x .* u.y .* p[1]
-    du.y .= -1 .* u.y .* p[2]
+    return du.y .= -1 .* u.y .* p[2]
 end
 const n = 4
 u_0 = @LArray fill(1000.0, 2 * n) (x = (1:n), y = ((n + 1):(2 * n)))
